"use strict";
var __importDefault = (this && this.__importDefault) || function (mod) {
    return (mod && mod.__esModule) ? mod : { "default": mod };
};
Object.defineProperty(exports, "__esModule", { value: true });
exports.callCloudMethod = void 0;
const error_1 = require("../error");
const vm_1 = __importDefault(require("vm"));
async function callCloudMethod(params, context) {
    try {
        const vmModule = {
            // eslint-disable-next-line @typescript-eslint/no-unused-vars
            exports(params, context) { },
        };
        const vmContext = {
            module: vmModule,
            require,
            TCBError: error_1.TCBError,
            Buffer,
            setTimeout,
            setInterval,
            setImmediate,
            clearTimeout,
            clearInterval,
            clearImmediate,
            /**
             * 暴露 process
             *  允许用户通过 process.env['NODE_TLS_REJECT_UNAUTHORIZED'] = 0 来规避请求部分网站可能出现的证书问题
             */
            process,
        };
        vm_1.default.createContext(vmContext);
        vm_1.default.runInNewContext(params.methodCfg.calleeBody.callee, vmContext);
        const result = await vmModule.exports(params.params, context);
        return result;
    }
    catch (e) {
        let code = 'FnError.Cloud';
        if (e.name)
            code += `.${e.code || e.name}`;
        throw new error_1.TCBError(code, `数据源自定义方法调用失败: ${e.message}`, {
            original: e,
        });
    }
}
exports.callCloudMethod = callCloudMethod;
