"use strict";
Object.defineProperty(exports, "__esModule", { value: true });
exports.callHttpMethod = void 0;
const send_request_1 = require("./send-request");
const json_transform_1 = require("./json-transform");
const field_2_template_1 = require("./field-2-template");
const error_1 = require("../error");
/**
 * 调用HTTP方法
 */
function callHttpMethod(options, context) {
    return send_request_1.sendRequest(options.dataSource, options.methodCfg, context, options.params)
        .then(async ({ response, body }) => {
        var _a;
        const bodyType = typeof body;
        let parsedBody;
        if (bodyType === 'object') {
            parsedBody = body;
        }
        else if (bodyType === 'string') {
            try {
                parsedBody = JSON.parse(body);
            }
            catch (error) {
                throw new error_1.TCBError('UserError.HTTP.InvalidResponse', '第三方接口返回的内容不是合法的JSON字符串', {
                    reason: `invalid response body, expect a json string: ${body}`,
                    original: error,
                });
            }
        }
        else {
            throw new error_1.TCBError('UserError.HTTP.InvalidResponse', `无法处理第三方接口返回的数据类型 ${bodyType}`, {
                reason: `unsupported response body type ${bodyType}`,
            });
        }
        if ((_a = context.httpAuth) === null || _a === void 0 ? void 0 : _a.transformResponse) {
            parsedBody = await context.httpAuth.transformResponse(parsedBody, response);
            response.body = parsedBody;
        }
        if (options.isTestMode) {
            return { response, body: parsedBody };
        }
        try {
            const paramsTpl = field_2_template_1.convertField2Template(options.methodCfg.outParams);
            const result = json_transform_1.transformJSONWithTemplate(parsedBody, paramsTpl);
            return result;
        }
        catch (error) {
            throw new error_1.TCBError('FnError.HTTP.MalformedResponse', `无法将第三方接口返回的数据转换为该数据源方法出参对应的结构: ${error.message}`, {
                reason: `failed to map origin response to method ${options.methodName}'s outParams specified structure, ${error.message}`,
                original: error,
            });
        }
    });
}
exports.callHttpMethod = callHttpMethod;
